@@ -74,8 +74,9 @@ get_currency <- function(strings) {
 #' removing all instances of duplication). This is vectorized over string and
 #' pattern.
 #' @param string A character vector. The string(s) to be purged of duplicates.
-#' @param pattern A character vector. Regular expression(s) of the pattern(s)
-#'   that we wish not to be duplicated.
+#' @param pattern A character vector. Pattern(s) specified like the pattern(s)
+#'   in the stringr package (e.g. look at [stringr::str_locate()]). If
+#'   this has length >1 its length must be the same as that of `string`.
 #' @return The string with the duplicates fixed.
 #' @examples
 #' singleize("abc//def", "/")
@@ -90,10 +91,10 @@ singleize <- function(string, pattern) {
 
 #' Make string numbers comply with alphabetical order
 #'
-#' If strings are numbered, their numbers may not \emph{comply} with
+#' If strings are numbered, their numbers may not *comply* with
 #' alphabetical order, i.e. "abc2" comes after "abc10" in alphabetical order. We
 #' might (for whatever reason) wish to change them such that they come in the
-#' order \emph{that we would like}. This function alters the strings such that
+#' order *that we would like*. This function alters the strings such that
 #' they comply with alphabetical order, so here "abc2" would be renamed to
 #' "abc02". It works on file names with more than one number in them e.g.
 #' "abc01def3" (a string with 2 numbers). All the file names that it works on
@@ -424,7 +425,7 @@ str_to_vec <- function(string) {
 #' @param patterns Regular expressions.
 #' @param ignore_case Do we want to ignore case when matching patterns?
 #' @param any Set this to `TRUE` if you want to see which strings match
-#'   \emph{any} of the patterns and not \emph{all} (all is the default).
+#'   *any* of the patterns and not *all* (all is the default).
 #'
 #' @return A character vector of strings matching the patterns.
 #'
@@ -465,10 +466,10 @@ str_with_patterns <- function(strings, patterns, ignore_case = FALSE,
 #' `str_before_last(...)` is just `str_before_nth(..., n = -1)`. }
 #'
 #' @param strings A character vector.
-#' @param pattern A regular expression.
+#' @inheritParams singleize
 #' @param n A natural number to identify the \eqn{n}th occurrence (defaults to
 #'   first (`n = 1`)). This can be negatively indexed, so if you wish to select
-#'   the \emph{last} occurrence, you need `n = -1`, for the second-last, you
+#'   the *last* occurrence, you need `n = -1`, for the second-last, you
 #'   need `n = -2` and so on.
 #' @return A character vector of the desired strings.
 #' @examples
@@ -608,7 +609,7 @@ put_in_pos <- function(strings, positions) {
 #' side(s).
 #'
 #' @param string A string.
-#' @param pattern A string. The pattern to be trimmed (\emph{not} interpreted as
+#' @param pattern A string. The pattern to be trimmed (*not* interpreted as
 #'   regular expression). So to trim a period, use `char = "."` and not
 #'   `char = "\\\\."`).
 #' @param side Which side do you want to trim from? `"both"` is the
@@ -768,9 +769,7 @@ str_split_camel_case <- function(string, lower = FALSE) {
 #'
 #' @param string A character vector. These functions are vectorized over this
 #'   argument.
-#' @param pattern A character vector. Pattern(s) specified like the pattern(s)
-#'   in the `stringr`` package (e.g. look at [stringr::str_locate()]). If this
-#'   has length >1 its length must be the same as that of `string`.
+#' @inheritParams singleize
 #' @param n Then \eqn{n} for the \eqn{n}th instance of the pattern.
 #'
 #' @return A two-column matrix. The \eqn{i}th row of this matrix gives the start
@@ -816,3 +815,126 @@ str_first_instance_indices <- function(string, pattern) {
 str_last_instance_indices <- function(string, pattern) {
   str_nth_instance_indices(string = string, pattern = pattern, n = -1)
 }
+
+#' Find the \eqn{n}th number after the \eqn{m}th occurrence of a pattern.
+#'
+#' Given a string, a pattern and natural numbers `n` and `m`, find the `n`th
+#' number after the `m`th occurrence of the pattern.
+#'
+#' @param string A character vector.
+#' @param n,m Natural numbers.
+#' @inheritParams singleize
+#' @inheritParams extract_numbers
+#'
+#' @return A numeric vector.
+#'
+#' @examples
+#' string <- c("abc1abc2abc3abc4abc5abc6abc7abc8abc9",
+#'             "abc1def2ghi3abc4def5ghi6abc7def8ghi9")
+#' nth_number_after_mth(string, "abc", 1, 3)
+#' nth_number_after_mth(string, "abc", 2, 3)
+#' @export
+nth_number_after_mth <- function(string, pattern, n, m,
+                                 decimals = FALSE, leading_decimals = FALSE,
+                                 negs = FALSE, leave_as_string = FALSE) {
+  string %>%
+    str_after_nth(pattern, m) %>%
+    nth_number(n, decimals = decimals, leading_decimals = leading_decimals,
+               negs = negs, leave_as_string = leave_as_string)
+}
+
+#' @rdname nth_number_after_mth
+#' @examples
+#' nth_number_after_first(string, "abc", 2)
+#' @export
+nth_number_after_first <- function(string, pattern, n,
+                                   decimals = FALSE, leading_decimals = FALSE,
+                                   negs = FALSE, leave_as_string = FALSE) {
+  nth_number_after_mth(string, pattern, n = n, m = 1,
+                       decimals = decimals, leading_decimals = leading_decimals,
+                       negs = negs, leave_as_string = leave_as_string)
+}
+
+#' @rdname nth_number_after_mth
+#' @examples
+#' nth_number_after_last(string, "abc", -1)
+#' @export
+nth_number_after_last <- function(string, pattern, n,
+                                  decimals = FALSE, leading_decimals = FALSE,
+                                  negs = FALSE, leave_as_string = FALSE) {
+  nth_number_after_mth(string, pattern, n = n, m = -1,
+                       decimals = decimals, leading_decimals = leading_decimals,
+                       negs = negs, leave_as_string = leave_as_string)
+}
+
+#' @rdname nth_number_after_mth
+#' @examples
+#' first_number_after_mth(string, "abc", 2)
+#' @export
+first_number_after_mth <- function(string, pattern, m,
+                                   decimals = FALSE, leading_decimals = FALSE,
+                                   negs = FALSE, leave_as_string = FALSE) {
+  nth_number_after_mth(string, pattern, n = 1, m = m,
+                       decimals = decimals, leading_decimals = leading_decimals,
+                       negs = negs, leave_as_string = leave_as_string)
+}
+
+#' @rdname nth_number_after_mth
+#' @examples
+#' last_number_after_mth(string, "abc", 1)
+#' @export
+last_number_after_mth <- function(string, pattern, m,
+                                  decimals = FALSE, leading_decimals = FALSE,
+                                  negs = FALSE, leave_as_string = FALSE) {
+  nth_number_after_mth(string, pattern, n = -1, m = m,
+                       decimals = decimals, leading_decimals = leading_decimals,
+                       negs = negs, leave_as_string = leave_as_string)
+}
+
+#' @rdname nth_number_after_mth
+#' @examples
+#' first_number_after_first(string, "abc")
+#' @export
+first_number_after_first <- function(string, pattern,
+                                     decimals = FALSE, leading_decimals = FALSE,
+                                     negs = FALSE, leave_as_string = FALSE) {
+  nth_number_after_mth(string, pattern, n = 1, m = 1,
+                       decimals = decimals, leading_decimals = leading_decimals,
+                       negs = negs, leave_as_string = leave_as_string)
+}
+
+#' @rdname nth_number_after_mth
+#' @examples
+#' first_number_after_last(string, "abc")
+#' @export
+first_number_after_last <- function(string, pattern,
+                                    decimals = FALSE, leading_decimals = FALSE,
+                                    negs = FALSE, leave_as_string = FALSE) {
+  nth_number_after_mth(string, pattern, n = 1, m = -1,
+                       decimals = decimals, leading_decimals = leading_decimals,
+                       negs = negs, leave_as_string = leave_as_string)
+}
+
+#' @rdname nth_number_after_mth
+#' @examples
+#' last_number_after_first(string, "abc")
+#' @export
+last_number_after_first <- function(string, pattern,
+                                    decimals = FALSE, leading_decimals = FALSE,
+                                    negs = FALSE, leave_as_string = FALSE) {
+  nth_number_after_mth(string, pattern, n = -1, m = 1,
+                       decimals = decimals, leading_decimals = leading_decimals,
+                       negs = negs, leave_as_string = leave_as_string)
+}
+
+#' @rdname nth_number_after_mth
+#' @examples
+#' last_number_after_last(string, "abc")
+#' @export
+last_number_after_last <- function(string, pattern,
+                                   decimals = FALSE, leading_decimals = FALSE,
+                                   negs = FALSE, leave_as_string = FALSE) {
+  nth_number_after_mth(string, pattern, n = -1, m = -1,
+                       decimals = decimals, leading_decimals = leading_decimals,
+                       negs = negs, leave_as_string = leave_as_string)
+}
